.. PyZoltan documentation master file, created by
   sphinx-quickstart on Fri Nov 30 00:39:26 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PyZoltan's documentation!
====================================

PyZoltan is as the name suggests, is a Python wrapper for the Zoltan_
data management library.

.. _Zoltan: http://www.cs.sandia.gov/Zoltan/

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   start.rst
   overview.rst

************************
Reference documentation
************************

Autogenerated from doc strings using sphinx's autodoc feature.

.. toctree::
   :maxdepth: 2

   reference/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
